@@ -123,6 +123,6 @@ rNBII <- function(n, mu=1, sigma=1)
           n <- ceiling(n)
           p <- runif(n)
           r <- qNBII(p, mu=mu, sigma=sigma)
-          r
+          as.integer(r)
   }
 #------------------------------------------------------------------------------------------
