@@ -347,7 +347,7 @@ rSICHEL <- function(n, mu=1, sigma=1, nu=-0.5, max.value = 10000)
           n <- ceiling(n)
           p <- runif(n)
           r <- qSICHEL(p, mu=mu, sigma=sigma, nu=nu, max.value = max.value )
-          r
+          as.integer(r)
   }
 #----------------------------------------------------------------------------------------
 VSICHEL<- function(obj)
